aboutsummaryrefslogtreecommitdiffstats
path: root/resources/libraries/python/model/util.py
diff options
context:
space:
mode:
authorpmikus <peter.mikus@protonmail.ch>2022-11-24 13:27:53 +0000
committerPeter Mikus <peter.mikus@protonmail.ch>2022-12-06 07:03:47 +0000
commitbfbdfaedb044b7643b81f47e76285baedfee9e25 (patch)
tree2b37abee55771074daea09a7f3f973352cc2ce48 /resources/libraries/python/model/util.py
parentc0cbaf897aa00152c4ce21987b6eb2ec371be6b0 (diff)
feat(model): Cleanup and introduce telemetry
- Due to divergence from original design path the RAW was never consumed. It adds too much code complexity and requires processing on both storage and compute. Removing entirely to make modeling efficient. - log (apparently SSH) section will never be consumed in the way it is coded in model. This section is also not part of model schema itself due to the point above. - Introducing telemetry section that is going to carry telemetry items required for CDash. Signed-off-by: pmikus <peter.mikus@protonmail.ch> Change-Id: I7e0256c6c9715de8ee559eed29dce96329aac97d
Diffstat (limited to 'resources/libraries/python/model/util.py')
-rw-r--r--resources/libraries/python/model/util.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/resources/libraries/python/model/util.py b/resources/libraries/python/model/util.py
index 879f1f28b1..ff5042fa6c 100644
--- a/resources/libraries/python/model/util.py
+++ b/resources/libraries/python/model/util.py
@@ -1,4 +1,4 @@
-# Copyright (c) 2021 Cisco and/or its affiliates.
+# Copyright (c) 2022 Cisco and/or its affiliates.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at:
@@ -52,7 +52,7 @@ def descend(parent_node, key, default_factory=None):
def get_export_data():
"""Return raw_data member of export_json library instance.
This assumes the data has been initialized already.
Return None if Robot is not running.
@@ -62,8 +62,8 @@ def get_export_data():
:raises AttributeError: If library is not imported yet.
"""
instance = BuiltIn().get_library_instance(
- u"resources.libraries.python.model.export_json"
+ u"resources.libraries.python.model.ExportJson"
)
if instance is None:
return None
- return instance.raw_data
+ return instance.data
@@ -52,7 +52,7 @@ def descend(parent_node, key, default_factory=None):
def get_export_data():
- """Return raw_data member of export_json library instance.
+ """Return data member of ExportJson library instance.
This assumes the data has been initialized already.
Return None if Robot is not running.